@@ -2,8 +2,11 @@
 #'
 #' @description Displays the model equations for a polynomial model
 #' which description is provided as a matrix \code{K}, each column
-#' corresponding to one equation. The coefficients of the polynomial terms are given
-#' following the order defined by function \code{poLabs}.
+#' corresponding to one equation. The coefficients of the polynomial
+#' terms are given following the order defined by function \code{poLabs}.
+#' The matrix can also be provided in a list \code{K},
+#' in this case, the matrix should be located in \code{K$model[[selecmod]]}
+#' where selecmod should be provided as input parameter.
 #'
 #' @inheritParams poLabs
 #' @inheritParams derivODE2
@@ -28,6 +31,9 @@
 #' for \code{approx} = 1, 2, etc. then respectively 1, 2, etc.
 #' digits are added to the minimum number of digits corresponding
 #' to \code{approx = TRUE}.
+#' @param selecmod An integer providing the number in the sublist
+#' when the model matrix is provided in a list. Should not be
+#' provided (or NULL) if the model matrix is provided directly.
 #'
 #' @author Sylvain Mangiarotti
 #'
@@ -46,21 +52,36 @@
 #' KL[5,3] <- -0.123456789
 #' # Equations visualisation:
 #' # (a) by default, variables names X1, X2, X3 are used
-#' visuEq(nVar, dMax, KL)
+#' visuEq(KL, nVar, dMax)
 #' # (b) for susbstit=1, variables names x, y, y are used instead
-#' visuEq(nVar, dMax, KL, approx = TRUE, substit=1)
+#' visuEq(KL, nVar, dMax, approx = TRUE, substit=1)
 #' # (c) the name of the variables can also be chosen manualy
-#' visuEq(nVar, dMax, KL, approx = 3, substit=c('U', 'V', 'W'))
+#' visuEq(KL, nVar, dMax, approx = 3, substit=c('U', 'V', 'W'))
 #'
 #' # A canonical model can be provided as a single vector
 #' polyTerms <- c(0.2,0,-1,0.5,0,0,0,0,0,0)
-#' visuEq(3,2,KL)
+#' visuEq(KL, 3,2)
 #'
 #' @export
-visuEq <- function (nVar, dMax, K, substit = 0, approx = FALSE) {
+visuEq <- function (K, nVar=NULL, dMax=NULL, substit = 0, approx = FALSE, selecmod = NULL) {
+  if (is.list(K)) {
+    if (is.null(selecmod)) {
+      stop('The model number should be provided using option: selecmod = ')
+      }
+    if (length(selecmod)!=1) {
+      stop('selecmod should be an integer. Only a single model can be displayed')
+    }
+    K <- K$models[[selecmod]]
+#    nVar <- dim(K)[2]
+#    dMax <- p2dMax(nVar = nVar, pMaxKnown = dim(K)[1])
+  }
   if (is.vector(K)) {
     K <- cano2M(nVar, dMax, K)
   }
+  if (is.matrix(K)) {
+    if (is.null(nVar)) nVar <- dim(K)[2]
+    if (is.null(dMax)) dMax <- p2dMax(nVar = nVar, pMaxKnown = dim(K)[1])
+  }
   # Check compatibility
   if (dim(K)[2] != nVar) {
     stop('nVar = ', nVar,
@@ -89,58 +110,49 @@ visuEq <- function (nVar, dMax, K, substit = 0, approx = FALSE) {
   #
   N <- list()
   for (i in 1:nVar) {
-    dN <- paste("dX", i,"/dt =", sep="")
-    M <- cbind(K[K[,i]!=0,i], poLabs(nVar, dMax, K[,i]!=0), "+")
+    if (!is.numeric(substit[1])) {
+      varsList = substit
+    }
+    else {
+      if (substit == 0) {
+        varsList = c("X1", "X2", "X3", "X4", "X5", "X6", "X7", "X8", "X9")
+      }
+      else if (substit == 1) {
+        varsList = c("x", "y", "z", "w", "u", "v", "r", "s", "q")
+      }
+      else if (substit == 2) {
+        varsList = c("X_1", "X_2", "X_3", "X_4", "X_5", "X_6", "X_7", "X_8", "X_9")
+        
+      }
+      else {
+        stop("substit must be either a list of nVar values or equal to 0 or 1 or 2")
+      }
+    }
+    dN <- paste("d", varsList[i],"/dt =", sep="")
+    M <- cbind(K[K[,i]!=0,i], poLabs(nVar, dMax, K[,i]!=0, Xnote=varsList[1:nVar]), "+")
+ 
     M <- matrix(t(M), nrow=1, ncol=length(M))
     M <- M[,1:(dim(M)[2]-1)]
     M <- cbind(dN, t(M))
     M <- paste(M,collapse=" ")
-    M <- gsub(" 1 X", " X", M, fixed=TRUE)
-    M <- gsub("-1 X", "-X", M, fixed=TRUE)
+    for (i in 1:nVar) {    
+       M <- gsub(paste("1 ", varsList[i]), varsList[i], M, fixed=TRUE)
+    }
     M <- gsub(" + -", " -", M, fixed=TRUE)
     M <- gsub("+  -", " -", M, fixed=TRUE)
     M <- gsub("+ -", " -", M, fixed=TRUE)
     M <- gsub(" +-", " -", M, fixed=TRUE)
     M <- gsub("ct", "", M)
     M <- gsub("Ct", "", M)
-    if (substit[1] == 1) {
-      M <- gsub("X1", "x", M)
-      M <- gsub("X2", "y", M)
-      M <- gsub("X3", "z", M)
-      M <- gsub("X4", "w", M)
-      M <- gsub("X5", "u", M)
-      M <- gsub("X6", "v", M)
-      M <- gsub("X7", "r", M)
-      M <- gsub("X8", "s", M)
-      M <- gsub("X9", "q", M)
-    }
     if (substit[1] == 2) {
-      M <- gsub("X1", "X_1", M)
-      M <- gsub("X2", "X_2", M)
-      M <- gsub("X3", "X_3", M)
-      M <- gsub("X4", "X_4", M)
-      M <- gsub("X5", "X_5", M)
-      M <- gsub("X6", "X_6", M)
-      M <- gsub("X7", "X_7", M)
-      M <- gsub("X8", "X_8", M)
-      M <- gsub("X9", "X_9", M)
+      # substitutions needed to agree with latex notation
       M <- gsub("e-0", "e-", M)
       M <- gsub("e+0", "e+", M)
       M <- gsub("e", ".10^{", M)
       M <- gsub("+-", "-", M)
       M <- gsub("+ -", "-", M)
     }
-    if (!is.numeric(substit[1])) {
-      M <- gsub("X1", substit[1], M)
-      M <- gsub("X2", substit[2], M)
-      M <- gsub("X3", substit[3], M)
-      M <- gsub("X4", substit[4], M)
-      M <- gsub("X5", substit[5], M)
-      M <- gsub("X6", substit[6], M)
-      M <- gsub("X7", substit[7], M)
-      M <- gsub("X8", substit[8], M)
-      M <- gsub("X9", substit[9], M)
-    }
+
     # plot expression ...
     cat(M, "\n\n")
     N[i] <- M
